@@ -7,6 +7,7 @@
 
 #include "msfileaccessor.h"
 #include "pwizmsfilereader.h"
+#include "pappsomspp/core/msfile/mzcbormsfilereader.h"
 #include "pappsomspp/core/msfile/timsmsfilereader.h"
 #include "pappsomspp/core/msfile/bafasciifilereader.h"
 #include "pappsomspp/core/msfile/xymsfilereader.h"
@@ -15,6 +16,7 @@
 #include "pappsomspp/core/exception/exceptionnotpossible.h"
 #include "pappsomspp/core/exception/exceptionnotrecognized.h"
 #include "pappsomspp/core/msrun/msrunid.h"
+#include "pappsomspp/core/msrun/private/mzcbormsrunreader.h"
 #include "pappsomspp/core/msrun/private/timsframesmsrunreader.h"
 
 #include "pappsomspp/core/msrun/private/pwizmsrunreader.h"
@@ -136,6 +138,13 @@ MsFileAccessor::getOboPsiModTermFileFormat() const
         term.m_name       = "mzML format";
         term.m_definition = "Proteomics Standards Inititative mzML file format.";
         break;
+      case Enums::MsDataFormat::mzcbor:
+        // mzCBOR is a direct translation of mzML
+        // waiting for a true OBO term, we choose the mzML definition
+        term.setAccession("MS:1000584");
+        term.m_name       = "mzML format";
+        term.m_definition = "Proteomics Standards Inititative mzML file format.";
+        break;
       case Enums::MsDataFormat::mzXML:
         term.setAccession("MS:1000566");
         term.m_name       = "ISB mzXML format";
@@ -192,13 +201,28 @@ MsFileAccessor::getOboPsiModTermNativeIDFormat() const
 std::vector<MsRunIdCstSPtr>
 MsFileAccessor::getMsRunIds()
 {
-  // qDebug();
+  qDebug();
+  // if (mzcbor_ms_file_reader.accept(m_fileName)) {
+  // }
+  std::vector<MsRunIdCstSPtr> ms_run_ids;
+
+
+  // try the mzcbor file reader
+  MzcborMsFileReader mzcbor_ms_file_reader(m_fileName);
+  if(mzcbor_ms_file_reader.getFileFormat() == pappso::Enums::MsDataFormat::mzcbor)
+    {
+      qDebug() << "sure, this is mzcbor";
+
+      ms_run_ids   = mzcbor_ms_file_reader.getMsRunIds(m_xmlPrefix);
+      m_fileFormat = Enums::MsDataFormat::mzcbor;
+      return ms_run_ids;
+    }
 
   // Try the PwizMsFileReader
 
   PwizMsFileReader pwiz_ms_file_reader(m_fileName);
 
-  std::vector<MsRunIdCstSPtr> ms_run_ids = pwiz_ms_file_reader.getMsRunIds(m_xmlPrefix);
+  ms_run_ids = pwiz_ms_file_reader.getMsRunIds(m_xmlPrefix);
   if(ms_run_ids.size())
     {
       qDebug() << "Might well be handled using the Pwiz code.";
@@ -307,6 +331,7 @@ MsFileAccessor::getMsRunIds()
 
   qDebug() << "The XY reader did not work.";
 
+
   return ms_run_ids;
 }
 
@@ -397,7 +422,7 @@ MsFileAccessor::buildTimsMsRunReaderMs2SPtr()
 MsRunReaderSPtr
 MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
 {
-  // qDebug();
+  qDebug();
 
   // We want to return a MsRunReader that accounts for the configuration that
   // the user might have set.
@@ -407,7 +432,13 @@ MsFileAccessor::msRunReaderSPtr(MsRunIdCstSPtr ms_run_id)
       ExceptionNotPossible(QObject::tr("The MsRunId instance must have the name file name as the "
                                        "MsFileAccessor.")));
 
-  if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::pwiz)
+  if(m_fileFormat == Enums::MsDataFormat::mzcbor)
+    {
+      qDebug() << "Returning a MzcborMsRunReader.";
+
+      return std::make_shared<MzcborMsRunReader>(ms_run_id);
+    }
+  else if(getpreferredFileReaderType(m_fileFormat) == Enums::FileReaderType::pwiz)
     {
       qDebug() << "Returning a PwizMsRunReader.";
       auto pwiz_reader              = std::make_shared<PwizMsRunReader>(ms_run_id);
@@ -545,6 +576,10 @@ MsFileAccessor::buildMsRunReaderSPtr(MsRunIdCstSPtr ms_run_id,
       // qDebug() << "by default, build a TimsMsRunReader.";
       return std::make_shared<TimsMsRunReader>(ms_run_id);
     }
+  else if(file_format == Enums::MsDataFormat::mzcbor)
+    {
+      return std::make_shared<MzcborMsRunReader>(ms_run_id);
+    }
   else
     {
       // qDebug() << "Returning a PwizMsRunReader .";
