@@ -26,6 +26,7 @@
  ******************************************************************************/
 #pragma once
 
+#include "pappsomspp/export-import-config.h"
 #include <map>
 #include <QString>
 #include "pappsomspp/core/protein/protein.h"
@@ -51,7 +52,7 @@ struct PsmProtein
 /** @brief store PsmProtein in a map with accession as key
  *
  */
-class PsmProteinMap
+class PMSPP_LIB_DECL PsmProteinMap
 {
   public:
   /**
