@@ -83,28 +83,29 @@ TimsDdaPrecursors::getSpectrumDescrListByFrameId(std::size_t frame_id) const
 
       QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
 
-      QSqlQuery q = qdb.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
-                                     "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
-                                     "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
-                                     "PasefFrameMsMsInfo.IsolationMz, "     // 3
-                                     "PasefFrameMsMsInfo.IsolationWidth, "  // 4
-                                     "PasefFrameMsMsInfo.CollisionEnergy, " // 5
-                                     "PasefFrameMsMsInfo.Precursor, "       // 6
-                                     "Precursors.Id, "                      // 7
-                                     "Precursors.LargestPeakMz, "           // 8
-                                     "Precursors.AverageMz, "               // 9
-                                     "Precursors.MonoisotopicMz, "          // 10
-                                     "Precursors.Charge, "                  // 11
-                                     "Precursors.ScanNumber, "              // 12
-                                     "Precursors.Intensity, "               // 13
-                                     "Precursors.Parent "                   // 14
-                                     "FROM PasefFrameMsMsInfo "
-                                     "INNER JOIN Precursors ON "
+      QSqlQuery q(qdb);
+      q.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
+                     "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
+                     "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
+                     "PasefFrameMsMsInfo.IsolationMz, "     // 3
+                     "PasefFrameMsMsInfo.IsolationWidth, "  // 4
+                     "PasefFrameMsMsInfo.CollisionEnergy, " // 5
+                     "PasefFrameMsMsInfo.Precursor, "       // 6
+                     "Precursors.Id, "                      // 7
+                     "Precursors.LargestPeakMz, "           // 8
+                     "Precursors.AverageMz, "               // 9
+                     "Precursors.MonoisotopicMz, "          // 10
+                     "Precursors.Charge, "                  // 11
+                     "Precursors.ScanNumber, "              // 12
+                     "Precursors.Intensity, "               // 13
+                     "Precursors.Parent "                   // 14
+                     "FROM PasefFrameMsMsInfo "
+                     "INNER JOIN Precursors ON "
 
 
-                                     "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                                     "WHERE PasefFrameMsMsInfo.Frame=%1;")
-                               .arg(frame_id));
+                     "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+                     "WHERE PasefFrameMsMsInfo.Frame=%1;")
+               .arg(frame_id));
       if(q.lastError().isValid())
         {
           qDebug();
@@ -170,11 +171,12 @@ TimsDdaPrecursors::getCombinedMs2ScansByPrecursorId(std::size_t precursor_id)
     {
       QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
 
-      QSqlQuery q = qdb.exec(QString("SELECT PasefFrameMsMsInfo.*, Precursors.* FROM "
-                                     "PasefFrameMsMsInfo INNER JOIN Precursors ON "
-                                     "PasefFrameMsMsInfo.Precursor=Precursors.Id where "
-                                     "Precursors.Id=%1;")
-                               .arg(precursor_id));
+      QSqlQuery q(qdb);
+      q.exec(QString("SELECT PasefFrameMsMsInfo.*, Precursors.* FROM "
+                     "PasefFrameMsMsInfo INNER JOIN Precursors ON "
+                     "PasefFrameMsMsInfo.Precursor=Precursors.Id where "
+                     "Precursors.Id=%1;")
+               .arg(precursor_id));
       if(q.lastError().isValid())
         {
           qDebug();
@@ -323,18 +325,19 @@ TimsDdaPrecursors::getXicCoordTimsFromPrecursorId(std::size_t precursor_id,
 
 
           QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
-          QSqlQuery q =
-            qdb.exec(QString("SELECT Precursors.id, "
-                             "min(Frames.Time), "
-                             "min(PasefFrameMsMsInfo.ScanNumBegin), "
-                             "max(PasefFrameMsMsInfo.ScanNumEnd), "
-                             "Precursors.MonoisotopicMz "
-                             "FROM "
-                             "PasefFrameMsMsInfo INNER JOIN Precursors ON "
-                             "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                             "INNER JOIN Frames ON "
-                             "PasefFrameMsMsInfo.Frame=Frames.Id "
-                             "GROUP BY Precursors.id;"));
+          QSqlQuery q(qdb);
+          q.exec(
+            QString("SELECT Precursors.id, "
+                    "min(Frames.Time), "
+                    "min(PasefFrameMsMsInfo.ScanNumBegin), "
+                    "max(PasefFrameMsMsInfo.ScanNumEnd), "
+                    "Precursors.MonoisotopicMz "
+                    "FROM "
+                    "PasefFrameMsMsInfo INNER JOIN Precursors ON "
+                    "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+                    "INNER JOIN Frames ON "
+                    "PasefFrameMsMsInfo.Frame=Frames.Id "
+                    "GROUP BY Precursors.id;"));
           if(q.lastError().isValid())
             {
               qDebug();
@@ -396,28 +399,29 @@ TimsDdaPrecursors::getSpectrumDescrWithPrecursorId(std::size_t precursor_id) con
 
   SpectrumDescr spectrum_descr;
   QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
-  QSqlQuery q      = qdb.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
-                                 "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
-                                 "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
-                                 "PasefFrameMsMsInfo.IsolationMz, "     // 3
-                                 "PasefFrameMsMsInfo.IsolationWidth, "  // 4
-                                 "PasefFrameMsMsInfo.CollisionEnergy, " // 5
-                                 "PasefFrameMsMsInfo.Precursor, "       // 6
-                                 "Precursors.Id, "                      // 7
-                                 "Precursors.LargestPeakMz, "           // 8
-                                 "Precursors.AverageMz, "               // 9
-                                 "Precursors.MonoisotopicMz, "          // 10
-                                 "Precursors.Charge, "                  // 11
-                                 "Precursors.ScanNumber, "              // 12
-                                 "Precursors.Intensity, "               // 13
-                                 "Precursors.Parent "                   // 14
-                                 "FROM PasefFrameMsMsInfo "
-                                      "INNER JOIN Precursors ON "
+  QSqlQuery q(qdb);
+  q.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
+                 "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
+                 "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
+                 "PasefFrameMsMsInfo.IsolationMz, "     // 3
+                 "PasefFrameMsMsInfo.IsolationWidth, "  // 4
+                 "PasefFrameMsMsInfo.CollisionEnergy, " // 5
+                 "PasefFrameMsMsInfo.Precursor, "       // 6
+                 "Precursors.Id, "                      // 7
+                 "Precursors.LargestPeakMz, "           // 8
+                 "Precursors.AverageMz, "               // 9
+                 "Precursors.MonoisotopicMz, "          // 10
+                 "Precursors.Charge, "                  // 11
+                 "Precursors.ScanNumber, "              // 12
+                 "Precursors.Intensity, "               // 13
+                 "Precursors.Parent "                   // 14
+                 "FROM PasefFrameMsMsInfo "
+                 "INNER JOIN Precursors ON "
 
 
-                                      "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                                      "WHERE Precursors.Id=%1;")
-                           .arg(precursor_id));
+                 "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+                 "WHERE Precursors.Id=%1;")
+           .arg(precursor_id));
   if(q.lastError().isValid())
     {
 
@@ -479,30 +483,31 @@ TimsDdaPrecursors::getSpectrumDescrWithScanCoordinates(
 
   SpectrumDescr spectrum_descr;
   QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
-  QSqlQuery q      = qdb.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
-                                 "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
-                                 "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
-                                 "PasefFrameMsMsInfo.IsolationMz, "     // 3
-                                 "PasefFrameMsMsInfo.IsolationWidth, "  // 4
-                                 "PasefFrameMsMsInfo.CollisionEnergy, " // 5
-                                 "PasefFrameMsMsInfo.Precursor, "       // 6
-                                 "Precursors.Id, "                      // 7
-                                 "Precursors.LargestPeakMz, "           // 8
-                                 "Precursors.AverageMz, "               // 9
-                                 "Precursors.MonoisotopicMz, "          // 10
-                                 "Precursors.Charge, "                  // 11
-                                 "Precursors.ScanNumber, "              // 12
-                                 "Precursors.Intensity, "               // 13
-                                 "Precursors.Parent "                   // 14
-                                 "FROM PasefFrameMsMsInfo "
-                                      "INNER JOIN Precursors ON "
-                                      "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                                      "WHERE "
-                                      "PasefFrameMsMsInfo.Frame=%1 and "
-                                      "(PasefFrameMsMsInfo.ScanNumBegin "
-                                      "<= %2 and PasefFrameMsMsInfo.ScanNumEnd >= %2);")
-                           .arg(scan_coordinates.first)
-                           .arg(scan_coordinates.second));
+  QSqlQuery q(qdb);
+  q.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
+                 "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
+                 "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
+                 "PasefFrameMsMsInfo.IsolationMz, "     // 3
+                 "PasefFrameMsMsInfo.IsolationWidth, "  // 4
+                 "PasefFrameMsMsInfo.CollisionEnergy, " // 5
+                 "PasefFrameMsMsInfo.Precursor, "       // 6
+                 "Precursors.Id, "                      // 7
+                 "Precursors.LargestPeakMz, "           // 8
+                 "Precursors.AverageMz, "               // 9
+                 "Precursors.MonoisotopicMz, "          // 10
+                 "Precursors.Charge, "                  // 11
+                 "Precursors.ScanNumber, "              // 12
+                 "Precursors.Intensity, "               // 13
+                 "Precursors.Parent "                   // 14
+                 "FROM PasefFrameMsMsInfo "
+                 "INNER JOIN Precursors ON "
+                 "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+                 "WHERE "
+                 "PasefFrameMsMsInfo.Frame=%1 and "
+                 "(PasefFrameMsMsInfo.ScanNumBegin "
+                 "<= %2 and PasefFrameMsMsInfo.ScanNumEnd >= %2);")
+           .arg(scan_coordinates.first)
+           .arg(scan_coordinates.second));
   if(q.lastError().isValid())
     {
 
@@ -889,26 +894,27 @@ TimsDdaPrecursors::ms2ReaderSpectrumCollectionByMsLevel(const MsRunIdCstSPtr &ms
   qDebug() << " ms_level=" << ms_level;
 
   QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
-  QSqlQuery qprecursor_list =
-    qdb.exec(QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
-                     "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
-                     "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
-                     "PasefFrameMsMsInfo.IsolationMz, "     // 3
-                     "PasefFrameMsMsInfo.IsolationWidth, "  // 4
-                     "PasefFrameMsMsInfo.CollisionEnergy, " // 5
-                     "PasefFrameMsMsInfo.Precursor, "       // 6
-                     "Precursors.Id, "                      // 7
-                     "Precursors.LargestPeakMz, "           // 8
-                     "Precursors.AverageMz, "               // 9
-                     "Precursors.MonoisotopicMz, "          // 10
-                     "Precursors.Charge, "                  // 11
-                     "Precursors.ScanNumber, "              // 12
-                     "Precursors.Intensity, "               // 13
-                     "Precursors.Parent "                   // 14
-                     "FROM PasefFrameMsMsInfo "
-                     "INNER JOIN Precursors ON "
-                     "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                     "ORDER BY PasefFrameMsMsInfo.Precursor, PasefFrameMsMsInfo.Frame ;"));
+  QSqlQuery qprecursor_list(qdb);
+  qprecursor_list.exec(
+    QString("SELECT PasefFrameMsMsInfo.Frame, "    // 0
+            "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
+            "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
+            "PasefFrameMsMsInfo.IsolationMz, "     // 3
+            "PasefFrameMsMsInfo.IsolationWidth, "  // 4
+            "PasefFrameMsMsInfo.CollisionEnergy, " // 5
+            "PasefFrameMsMsInfo.Precursor, "       // 6
+            "Precursors.Id, "                      // 7
+            "Precursors.LargestPeakMz, "           // 8
+            "Precursors.AverageMz, "               // 9
+            "Precursors.MonoisotopicMz, "          // 10
+            "Precursors.Charge, "                  // 11
+            "Precursors.ScanNumber, "              // 12
+            "Precursors.Intensity, "               // 13
+            "Precursors.Parent "                   // 14
+            "FROM PasefFrameMsMsInfo "
+            "INNER JOIN Precursors ON "
+            "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+            "ORDER BY PasefFrameMsMsInfo.Precursor, PasefFrameMsMsInfo.Frame ;"));
   if(qprecursor_list.lastError().isValid())
     {
 
@@ -1150,27 +1156,28 @@ TimsDdaPrecursors::rawReaderSpectrumCollectionByMsLevel(const MsRunIdCstSPtr &ms
   handler.spectrumListHasSize(spectrum_list_size);
 
   QSqlDatabase qdb = mp_timsDataOrigin->openDatabaseConnection();
-  QSqlQuery qprecursor_list =
-    qdb.exec(QString("SELECT DISTINCT "
-                     "PasefFrameMsMsInfo.Frame, "           // 0
-                     "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
-                     "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
-                     "PasefFrameMsMsInfo.IsolationMz, "     // 3
-                     "PasefFrameMsMsInfo.IsolationWidth, "  // 4
-                     "PasefFrameMsMsInfo.CollisionEnergy, " // 5
-                     "PasefFrameMsMsInfo.Precursor, "       // 6
-                     "Precursors.Id, "                      // 7
-                     "Precursors.LargestPeakMz, "           // 8
-                     "Precursors.AverageMz, "               // 9
-                     "Precursors.MonoisotopicMz, "          // 10
-                     "Precursors.Charge, "                  // 11
-                     "Precursors.ScanNumber, "              // 12
-                     "Precursors.Intensity, "               // 13
-                     "Precursors.Parent "                   // 14
-                     "FROM PasefFrameMsMsInfo "
-                     "INNER JOIN Precursors ON "
-                     "PasefFrameMsMsInfo.Precursor=Precursors.Id "
-                     "ORDER BY PasefFrameMsMsInfo.Frame, PasefFrameMsMsInfo.ScanNumBegin ;"));
+  QSqlQuery qprecursor_list(qdb);
+  qprecursor_list.exec(
+    QString("SELECT DISTINCT "
+            "PasefFrameMsMsInfo.Frame, "           // 0
+            "PasefFrameMsMsInfo.ScanNumBegin, "    // 1
+            "PasefFrameMsMsInfo.ScanNumEnd, "      // 2
+            "PasefFrameMsMsInfo.IsolationMz, "     // 3
+            "PasefFrameMsMsInfo.IsolationWidth, "  // 4
+            "PasefFrameMsMsInfo.CollisionEnergy, " // 5
+            "PasefFrameMsMsInfo.Precursor, "       // 6
+            "Precursors.Id, "                      // 7
+            "Precursors.LargestPeakMz, "           // 8
+            "Precursors.AverageMz, "               // 9
+            "Precursors.MonoisotopicMz, "          // 10
+            "Precursors.Charge, "                  // 11
+            "Precursors.ScanNumber, "              // 12
+            "Precursors.Intensity, "               // 13
+            "Precursors.Parent "                   // 14
+            "FROM PasefFrameMsMsInfo "
+            "INNER JOIN Precursors ON "
+            "PasefFrameMsMsInfo.Precursor=Precursors.Id "
+            "ORDER BY PasefFrameMsMsInfo.Frame, PasefFrameMsMsInfo.ScanNumBegin ;"));
   if(qprecursor_list.lastError().isValid())
     {
       throw PappsoException(
